@@ -356,8 +356,8 @@ class SimpleIMAPRetriever(IMAPRetrieverBase, IMAPinitMixIn):
         ConfInt(name='port', required=False, default=imaplib.IMAP4_PORT),
         ConfString(name='username'),
         ConfPassword(name='password', required=False, default=None),
-        ConfTupleOfStrings(name='mailboxes', required=False,
-                           default="('INBOX', )"),
+        ConfTupleOfUnicode(name='mailboxes', required=False,
+                           default="('INBOX', )", allow_specials=('ALL',)),
         ConfBool(name='use_peek', required=False, default=True),
         ConfString(name='move_on_delete', required=False, default=None),
         # imaplib.IMAP4.login_cram_md5() requires the (unimplemented)
@@ -396,8 +396,8 @@ class SimpleIMAPSSLRetriever(IMAPRetrieverBase, IMAPSSLinitMixIn):
         ConfInt(name='port', required=False, default=imaplib.IMAP4_SSL_PORT),
         ConfString(name='username'),
         ConfPassword(name='password', required=False, default=None),
-        ConfTupleOfStrings(name='mailboxes', required=False,
-                           default="('INBOX', )"),
+        ConfTupleOfUnicode(name='mailboxes', required=False,
+                           default="('INBOX', )", allow_specials=('ALL',)),
         ConfBool(name='use_peek', required=False, default=True),
         ConfString(name='move_on_delete', required=False, default=None),
         ConfFile(name='keyfile', required=False, default=None),
@@ -437,8 +437,8 @@ class MultidropIMAPRetriever(MultidropIMAPRetrieverBase, IMAPinitMixIn):
         ConfInt(name='port', required=False, default=imaplib.IMAP4_PORT),
         ConfString(name='username'),
         ConfPassword(name='password', required=False, default=None),
-        ConfTupleOfStrings(name='mailboxes', required=False,
-                           default="('INBOX', )"),
+        ConfTupleOfUnicode(name='mailboxes', required=False,
+                           default="('INBOX', )", allow_specials=('ALL',)),
         ConfBool(name='use_peek', required=False, default=True),
         ConfString(name='move_on_delete', required=False, default=None),
         # imaplib.IMAP4.login_cram_md5() requires the (unimplemented)
@@ -478,8 +478,8 @@ class MultidropIMAPSSLRetriever(MultidropIMAPRetrieverBase, IMAPSSLinitMixIn):
         ConfInt(name='port', required=False, default=imaplib.IMAP4_SSL_PORT),
         ConfString(name='username'),
         ConfPassword(name='password', required=False, default=None),
-        ConfTupleOfStrings(name='mailboxes', required=False,
-                           default="('INBOX', )"),
+        ConfTupleOfUnicode(name='mailboxes', required=False,
+                           default="('INBOX', )", allow_specials=('ALL',)),
         ConfBool(name='use_peek', required=False, default=True),
         ConfString(name='move_on_delete', required=False, default=None),
         ConfFile(name='keyfile', required=False, default=None),
